@@ -13,6 +13,8 @@ static const R_CallMethodDef callMethods[] = {
   {"R_Euler_Multinom", (DL_FUNC) &R_Euler_Multinom, 4},
   {"D_Euler_Multinom", (DL_FUNC) &D_Euler_Multinom, 5},
   {"R_GammaWN", (DL_FUNC) &R_GammaWN, 3},
+  {"R_BetaBinom", (DL_FUNC) &R_BetaBinom, 4},
+  {"D_BetaBinom", (DL_FUNC) &D_BetaBinom, 5},
   {"pfilter_computations", (DL_FUNC) &pfilter, 10},
   {"wpfilter_comps", (DL_FUNC) &wpfilter, 7},
   {"randwalk_perturbation", (DL_FUNC) &randwalk_perturbation, 2},
@@ -34,6 +36,8 @@ static const R_CallMethodDef callMethods[] = {
   {"do_dprocess", (DL_FUNC) &do_dprocess, 6},
   {"do_rmeasure", (DL_FUNC) &do_rmeasure, 5},
   {"do_dmeasure", (DL_FUNC) &do_dmeasure, 7},
+  {"do_emeasure", (DL_FUNC) &do_emeasure, 5},
+  {"do_vmeasure", (DL_FUNC) &do_vmeasure, 5},
   {"do_rprior", (DL_FUNC) &do_rprior, 3},
   {"do_dprior", (DL_FUNC) &do_dprior, 4},
   {"do_skeleton", (DL_FUNC) &do_skeleton, 5},
